summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/colourcombo.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/colourcombo.h')
-rw-r--r--kalarm/lib/colourcombo.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kalarm/lib/colourcombo.h b/kalarm/lib/colourcombo.h
index b05f7882..31fcdbdc 100644
--- a/kalarm/lib/colourcombo.h
+++ b/kalarm/lib/colourcombo.h
@@ -40,17 +40,18 @@
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class ColourCombo : public QComboBox
+class ColourCombo : public TQComboBox
{
Q_OBJECT
- Q_PROPERTY(TQColor color READ color WRITE setColor)
+ TQ_OBJECT
+ TQ_PROPERTY(TQColor color READ color WRITE setColor)
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
* @param defaultColour The colour which is selected by default.
*/
- explicit ColourCombo(TQWidget* parent = 0, const char* name = 0, const TQColor& defaultColour = 0xFFFFFF);
+ explicit ColourCombo(TQWidget* tqparent = 0, const char* name = 0, const TQColor& defaultColour = 0xFFFFFF);
/** Returns the selected colour. */
TQColor color() const { return mSelectedColour; }
/** Returns the selected colour. */
@@ -40,17 +40,18 @@
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
* @param defaultColour The colour which is selected by default.